---

name: 🐛 Bug Report
about: Create a report to help us improve pyinfra.
labels: Bug

---

## Describe the bug
A clear and concise description of what the bug is.

## To Reproduce
Steps to reproduce the behavior, please include where possible:

+ Operation code & usage
+ Target system information
+ Example using the `@docker` connector (helps isolate the problem)

## Expected behavior
A clear and concise description of what you expected to happen.

## Meta
+ Include output of `pyinfra --support`.
+ How was pyinfra installed (source/pip)?
+ Include pyinfra-debug.log (if one was created)
+ Consider including output with `-vv` and `--debug`.
